package fi.jyu.intellij.comtest.idea.actions

import com.intellij.openapi.actionSystem.ActionGroup
import com.intellij.openapi.actionSystem.AnAction
import com.intellij.openapi.actionSystem.AnActionEvent
import com.intellij.psi.PsiJavaFile
import fi.jyu.intellij.comtest.idea.util.getValidComTestTarget

/**
 * Dynamic popup action group for ComTest actions.
 *
 * The group is dynamically adjusted based on whether the user has selected a package or a Java file.
 */
@Suppress("ComponentNotRegistered", "MissingActionUpdateThread")
class ComTestJavaFileEditorPopupActionGroup : ActionGroup() {
    override fun getChildren(e: AnActionEvent?): Array<AnAction> {
        val target = e?.getValidComTestTarget() ?: return emptyArray()
        val targetName = if (target is PsiJavaFile) "File" else "Package"

        return arrayOf(
            ComTestGenerateRunAction().apply {
                templatePresentation.text = "Run in Current $targetName"
            },
            ComTestGenerateDebugAction().apply {
                templatePresentation.text = "Debug in Current $targetName"
            }
        )
    }

    override fun update(e: AnActionEvent) {
        super.update(e)
        e.presentation.isVisible = e.getValidComTestTarget() != null
    }
}