package fi.jyu.intellij.comtest.rider.actions

import com.intellij.openapi.actionSystem.AnAction
import com.intellij.openapi.actionSystem.AnActionEvent
import com.intellij.openapi.actionSystem.DataContext
import com.intellij.openapi.project.Project
import com.jetbrains.rider.projectView.workspace.getProjectModelEntities
import com.jetbrains.rider.projectView.workspace.isProject
import comtest.v2.processors.ComTestResult
import fi.jyu.intellij.comtest.common.util.runWithRefresh
import fi.jyu.intellij.comtest.rider.ComTestRunner
import fi.jyu.intellij.comtest.rider.util.hasRiderSolution

/**
 * Action to run ComTest on .NET
 */
@Suppress("MissingActionUpdateThread")
open class ComTestGenerateDotNetAction : AnAction() {

    protected fun execute(proj: Project, dataContext: DataContext, alwaysShowConsole: Boolean = false): ComTestResult? {
        val projectEntities = dataContext.getProjectModelEntities().filter { it.isProject() }.map { it.name }

        return runWithRefresh(proj) {
            ComTestRunner.generateForDotNet(proj, alwaysShowConsole, projectEntities)
        }
    }

    override fun actionPerformed(e: AnActionEvent) {
        val proj = e.project ?: return
        execute(proj, e.dataContext, true)
    }

    override fun update(e: AnActionEvent) {
        e.presentation.isEnabled = e.project?.hasRiderSolution ?: false
    }
}